@@ -1,7 +1,7 @@
-from . import GenericWorld, GenericWeb
+from . import DK64World, DK64Web
 
 """
-Generic World Registration
+DK64 World Registration
 
 This file contains the metadata and class references for the dk64 world.
 """
@@ -17,6 +17,6 @@ AUTHOR = author
 VERSION = version
 
 # Plugin entry points
-WORLD_CLASS = GenericWorld
-WEB_WORLD_CLASS = GenericWeb
+WORLD_CLASS = DK64World
+WEB_WORLD_CLASS = DK64Web
 CLIENT_FUNCTION = None
