@@ -336,106 +336,6 @@ location_flag_to_name = {
     708: "Aztec Vase: Triangle",
     709: "Aztec Vase: Plus",
     768: "Forest Second Anthill Reward",
-    800: "Japes Cranky Donkey",
-    801: "Japes Cranky Diddy",
-    802: "Japes Cranky Lanky",
-    803: "Japes Cranky Tiny",
-    804: "Japes Cranky Chunky",
-    805: "Aztec Cranky Donkey",
-    806: "Aztec Cranky Diddy",
-    807: "Aztec Cranky Lanky",
-    808: "Aztec Cranky Tiny",
-    809: "Aztec Cranky Chunky",
-    810: "Factory Cranky Donkey",
-    811: "Factory Cranky Diddy",
-    812: "Factory Cranky Lanky",
-    813: "Factory Cranky Tiny",
-    814: "Factory Cranky Chunky",
-    815: "Galleon Cranky Donkey",
-    816: "Galleon Cranky Diddy",
-    817: "Galleon Cranky Lanky",
-    818: "Galleon Cranky Tiny",
-    819: "Galleon Cranky Chunky",
-    820: "Forest Cranky Donkey",
-    821: "Forest Cranky Diddy",
-    822: "Forest Cranky Lanky",
-    823: "Forest Cranky Tiny",
-    824: "Forest Cranky Chunky",
-    825: "Caves Cranky Donkey",
-    826: "Caves Cranky Diddy",
-    827: "Caves Cranky Lanky",
-    828: "Caves Cranky Tiny",
-    829: "Caves Cranky Chunky",
-    830: "Castle Cranky Donkey",
-    831: "Castle Cranky Diddy",
-    832: "Castle Cranky Lanky",
-    833: "Castle Cranky Tiny",
-    834: "Castle Cranky Chunky",
-    835: "Isles Cranky Donkey",
-    836: "Isles Cranky Diddy",
-    837: "Isles Cranky Lanky",
-    838: "Isles Cranky Tiny",
-    839: "Isles Cranky Chunky",
-    840: "Japes Funky Donkey",
-    841: "Japes Funky Diddy",
-    842: "Japes Funky Lanky",
-    843: "Japes Funky Tiny",
-    844: "Japes Funky Chunky",
-    845: "Aztec Funky Donkey",
-    846: "Aztec Funky Diddy",
-    847: "Aztec Funky Lanky",
-    848: "Aztec Funky Tiny",
-    849: "Aztec Funky Chunky",
-    850: "Factory Funky Donkey",
-    851: "Factory Funky Diddy",
-    852: "Factory Funky Lanky",
-    853: "Factory Funky Tiny",
-    854: "Factory Funky Chunky",
-    855: "Galleon Funky Donkey",
-    856: "Galleon Funky Diddy",
-    857: "Galleon Funky Lanky",
-    858: "Galleon Funky Tiny",
-    859: "Galleon Funky Chunky",
-    860: "Forest Funky Donkey",
-    861: "Forest Funky Diddy",
-    862: "Forest Funky Lanky",
-    863: "Forest Funky Tiny",
-    864: "Forest Funky Chunky",
-    865: "Caves Funky Donkey",
-    866: "Caves Funky Diddy",
-    867: "Caves Funky Lanky",
-    868: "Caves Funky Tiny",
-    869: "Caves Funky Chunky",
-    870: "Castle Funky Donkey",
-    871: "Castle Funky Diddy",
-    872: "Castle Funky Lanky",
-    873: "Castle Funky Tiny",
-    874: "Castle Funky Chunky",
-    875: "Aztec Candy Donkey",
-    876: "Aztec Candy Diddy",
-    877: "Aztec Candy Lanky",
-    878: "Aztec Candy Tiny",
-    879: "Aztec Candy Chunky",
-    880: "Factory Candy Donkey",
-    881: "Factory Candy Diddy",
-    882: "Factory Candy Lanky",
-    883: "Factory Candy Tiny",
-    884: "Factory Candy Chunky",
-    885: "Galleon Candy Donkey",
-    886: "Galleon Candy Diddy",
-    887: "Galleon Candy Lanky",
-    888: "Galleon Candy Tiny",
-    889: "Galleon Candy Chunky",
-    890: "Caves Candy Donkey",
-    891: "Caves Candy Diddy",
-    892: "Caves Candy Lanky",
-    893: "Caves Candy Tiny",
-    894: "Caves Candy Chunky",
-    895: "Castle Candy Donkey",
-    896: "Castle Candy Diddy",
-    897: "Castle Candy Lanky",
-    898: "Castle Candy Tiny",
-    899: "Castle Candy Chunky",
     940: "Japes Crate: Behind the Mountain",
     941: "Japes Crate: In the Rambi Cave",
     942: "Aztec Crate: Llama Temple Entrance",
