@@ -5,6 +5,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 from randomizer.Enums.Levels import Levels
+from randomizer.Enums.Maps import Maps
 
 
 class MultiselectorItem:
@@ -239,6 +240,21 @@ cb_levels = {
     Levels.DKIsles: "DK Isles",
 }
 
+bosses = {
+    Maps.JapesBoss: "Army Dillo 1",
+    Maps.AztecBoss: "Dogadon 1",
+    Maps.FactoryBoss: "Mad Jack",
+    Maps.GalleonBoss: "Pufftoss",
+    Maps.FungiBoss: "Dogadon 2",
+    Maps.CavesBoss: "Army Dillo 2",
+    Maps.CastleBoss: "King Kut Out",
+    Maps.KroolDonkeyPhase: "K. Rool (Donkey Phase)",
+    Maps.KroolDiddyPhase: "K. Rool (Diddy Phase)",
+    Maps.KroolLankyPhase: "K. Rool (Lanky Phase)",
+    Maps.KroolTinyPhase: "K. Rool (Tiny Phase)",
+    Maps.KroolChunkyPhase: "K. Rool (Chunky Phase)",
+}
+
 CBRandoSelector = [
     {
         "name": name,
@@ -253,3 +269,12 @@ QoLSelector = parseMultiselector(QoLItems)
 RemovedBarrierSelector = parseMultiselector(RemovedBarrierItems)
 FasterCheckSelector = parseMultiselector(FasterCheckItems)
 RandomColorSelector = parseMultiselector(RandomColorItems)
+BossesSelector = [
+    {
+        "name": name,
+        "value": map_id.name,
+        "tooltip": name,
+        "shift": -1,
+    }
+    for map_id, name, in bosses.items()
+]
