@@ -14,26 +14,40 @@ from randomizer.Patching.Library.Image import (
     hueShift,
     hueShiftImageContainer,
 )
-from randomizer.Patching.Library.Assets import getPointerLocation, TableNames
+from randomizer.Patching.Library.Assets import getPointerLocation, TableNames, getRawFile, writeRawFile
 from randomizer.Settings import CharacterColors, KongModels, ColorOptions
 
 
-def changeBarrelColor(settings, ROM_COPY: ROM, barrel_color: tuple = None, metal_color: tuple = None, brighten_barrel: bool = False):
+def changeBarrelColor(settings, ROM_COPY: ROM, barrel_color: list[tuple] = [None] * 6, metal_color: tuple = None, brighten_barrel: bool = False):
     """Change the colors of the various barrels."""
+    if settings.color_coded_powerups:
+        barrel_color = [
+            (0xFF, 0xD7, 0x00),
+            (0xFF, 0x00, 0x00),
+            (0x16, 0x99, 0xFF),
+            (0xB0, 0x45, 0xFF),
+            (0x41, 0xFF, 0x25),
+            barrel_color[5],
+        ]
     wood_img = getImageFile(ROM_COPY, 25, getBonusSkinOffset(ExtraTextures.ShellWood), True, 32, 64, TextureFormat.RGBA5551)
     metal_img = getImageFile(ROM_COPY, 25, getBonusSkinOffset(ExtraTextures.ShellMetal), True, 32, 64, TextureFormat.RGBA5551)
     qmark_img = getImageFile(ROM_COPY, 25, getBonusSkinOffset(ExtraTextures.ShellQMark), True, 32, 64, TextureFormat.RGBA5551)
-    if barrel_color is not None:
-        if brighten_barrel:
-            enhancer = ImageEnhance.Brightness(wood_img)
-            wood_img = enhancer.enhance(2)
-        wood_img = maskImageWithColor(wood_img, barrel_color)
+    wood_imgs = []
+    for x in range(6):
+        wood_tmp = wood_img
+        if barrel_color[x] is not None:
+            if brighten_barrel:
+                enhancer = ImageEnhance.Brightness(wood_tmp)
+                wood_tmp = enhancer.enhance(2)
+            wood_tmp = maskImageWithColor(wood_tmp, barrel_color[x])
+        wood_imgs.append(wood_tmp)
     if metal_color is not None:
         metal_img = maskImageWithColor(metal_img, metal_color)
-    wood_img.paste(metal_img, (0, 0), metal_img)
-    writeColorImageToROM(wood_img, 25, getBonusSkinOffset(ExtraTextures.BonusShell), 32, 64, False, TextureFormat.RGBA5551, ROM_COPY)  # Bonus Barrel
+    for x in range(6):
+        wood_imgs[x].paste(metal_img, (0, 0), metal_img)
+    writeColorImageToROM(wood_imgs[5], 25, getBonusSkinOffset(ExtraTextures.BonusShell), 32, 64, False, TextureFormat.RGBA5551, ROM_COPY)  # Bonus Barrel
     tag_img = Image.new(mode="RGBA", size=(32, 64))
-    tag_img.paste(wood_img, (0, 0), wood_img)
+    tag_img.paste(wood_imgs[5], (0, 0), wood_imgs[5])
     tag_img.paste(qmark_img, (0, 0), qmark_img)
     writeColorImageToROM(tag_img, 25, 4938, 32, 64, False, TextureFormat.RGBA5551, ROM_COPY)  # Tag Barrel
     # Compose Transform Barrels
@@ -44,7 +58,7 @@ def changeBarrelColor(settings, ROM_COPY: ROM, barrel_color: tuple = None, metal
         {"face_left": 0x276, "face_right": 0x275, "barrel_tex_start": 4769, "targ_width": 24},  # Tiny
         {"face_left": 0x273, "face_right": 0x274, "barrel_tex_start": 4747, "targ_width": 24},  # Chunky
     ]
-    for kong in kongs:
+    for kong_index, kong in enumerate(kongs):
         bar_left = Image.new(mode="RGBA", size=(32, 64))
         bar_right = Image.new(mode="RGBA", size=(32, 64))
         face_left = getImageFile(ROM_COPY, 25, kong["face_left"], True, 32, 64, TextureFormat.RGBA5551)
@@ -55,8 +69,8 @@ def changeBarrelColor(settings, ROM_COPY: ROM, barrel_color: tuple = None, metal
         face_right = face_right.resize((width, height))
         right_w_offset = 32 - width
         top_h_offset = (64 - height) >> 1
-        bar_left.paste(wood_img, (0, 0), wood_img)
-        bar_right.paste(wood_img, (0, 0), wood_img)
+        bar_left.paste(wood_imgs[kong_index], (0, 0), wood_imgs[kong_index])
+        bar_right.paste(wood_imgs[kong_index], (0, 0), wood_imgs[kong_index])
         bar_left.paste(face_left, (right_w_offset, top_h_offset), face_left)
         bar_right.paste(face_right, (0, top_h_offset), face_right)
         writeColorImageToROM(bar_left, 25, kong["barrel_tex_start"], 32, 64, False, TextureFormat.RGBA5551, ROM_COPY)
@@ -64,13 +78,13 @@ def changeBarrelColor(settings, ROM_COPY: ROM, barrel_color: tuple = None, metal
     # Cannons
     barrel_left = Image.new(mode="RGBA", size=(32, 64))
     barrel_right = Image.new(mode="RGBA", size=(32, 64))
-    barrel_left.paste(wood_img, (0, 0), wood_img)
-    barrel_right.paste(wood_img, (0, 0), wood_img)
+    barrel_left.paste(wood_imgs[5], (0, 0), wood_imgs[5])
+    barrel_right.paste(wood_imgs[5], (0, 0), wood_imgs[5])
     barrel_left = barrel_left.crop((0, 0, 16, 64))
     barrel_right = barrel_right.crop((16, 0, 32, 64))
     writeColorImageToROM(barrel_left, 25, 0x12B3, 16, 64, False, TextureFormat.RGBA5551, ROM_COPY)
     writeColorImageToROM(barrel_right, 25, 0x12B4, 16, 64, False, TextureFormat.RGBA5551, ROM_COPY)
-    if barrel_color is not None:
+    if barrel_color[5] is not None:
         tex_data = {
             getBonusSkinOffset(ExtraTextures.RocketTop): (1, 1372),
             0x12B5: (48, 32),
@@ -80,10 +94,10 @@ def changeBarrelColor(settings, ROM_COPY: ROM, barrel_color: tuple = None, metal
             dim_x = tex_data[img][0]
             dim_y = tex_data[img][1]
             img_output = getImageFile(ROM_COPY, 25, img, True, dim_x, dim_y, TextureFormat.RGBA5551)
-            img_output = maskImageWithColor(img_output, barrel_color)
+            img_output = maskImageWithColor(img_output, barrel_color[5])
             writeColorImageToROM(img_output, 25, img, dim_x, dim_y, False, TextureFormat.RGBA5551, ROM_COPY)
     # Barrel Palette
-    if barrel_color is not None:
+    if barrel_color[5] is not None:
         palette_files = {
             0x145: [],
             0x147: [1, 3, 4, 6, 9, 10, 12, 15],
@@ -95,7 +109,7 @@ def changeBarrelColor(settings, ROM_COPY: ROM, barrel_color: tuple = None, metal
         }
         for img in palette_files:
             initial_img = getImageFile(ROM_COPY, 25, img, True, 16, 1, TextureFormat.RGBA5551)
-            img_output = maskImageWithColor(initial_img, barrel_color).convert("RGB")
+            img_output = maskImageWithColor(initial_img, barrel_color[5]).convert("RGB")
             pixels = palette_files[img]
             for px in pixels:
                 img_output.putpixel((px, 0), initial_img.getpixel((px, 0)))
@@ -152,6 +166,39 @@ def applyCelebrationRims(ROM_COPY: ROM, hue_shift: int, enabled_bananas: list[bo
 def applyHolidayMode(settings, ROM_COPY: ROM):
     """Change grass texture to snow."""
     HOLIDAY = getHoliday(settings)
+    if settings.color_coded_powerups:
+        pad_data = [
+            {"move_pad": 0x0097, "ins_pad": 0x00A8, "move_tex": [0xDEE, 0xDEF], "ins_tex": [getBonusSkinOffset(ExtraTextures.DonkeyPadLeft), getBonusSkinOffset(ExtraTextures.DonkeyPadRight)]},
+            {"move_pad": 0x00D4, "ins_pad": 0x00A9, "move_tex": [0xDF4, 0xDF5], "ins_tex": [getBonusSkinOffset(ExtraTextures.DiddyPadLeft), getBonusSkinOffset(ExtraTextures.DiddyPadRight)]},
+            {"move_pad": 0x010C, "ins_pad": 0x00AC, "move_tex": [0xBB0, 0xBB1], "ins_tex": [getBonusSkinOffset(ExtraTextures.LankyPadLeft), getBonusSkinOffset(ExtraTextures.LankyPadRight)]},
+            {"move_pad": 0x010B, "ins_pad": 0x00AA, "move_tex": [0xDF1, 0xDF2], "ins_tex": [0xBC5, 0xBC4]},
+            {"move_pad": 0x010A, "ins_pad": 0x00AB, "move_tex": [0xDF6, 0xDF7], "ins_tex": [getBonusSkinOffset(ExtraTextures.ChunkyPadLeft), getBonusSkinOffset(ExtraTextures.ChunkyPadRight)]},
+        ]
+        for kong in pad_data:
+            # Move pads: 0xEC (0), 0x164 (1)
+            # Instrument pads: 0xDC (1), 0x14C (0)
+            # Move Pads
+            data = getRawFile(ROM_COPY, TableNames.ModelTwoGeometry, kong["move_pad"], True)
+            num_data = []  # data, but represented as nums rather than b strings
+            for d in data:
+                num_data.append(d)
+            num_data[0x0EE] = (kong["move_tex"][0] >> 8) & 0xFF
+            num_data[0x0EF] = (kong["move_tex"][0] >> 0) & 0xFF
+            num_data[0x166] = (kong["move_tex"][1] >> 8) & 0xFF
+            num_data[0x167] = (kong["move_tex"][1] >> 0) & 0xFF
+            data = bytearray(num_data)  # convert num_data back to binary string
+            writeRawFile(TableNames.ModelTwoGeometry, kong["move_pad"], True, data, ROM_COPY)
+            # Instrument Pads
+            data = getRawFile(ROM_COPY, TableNames.ModelTwoGeometry, kong["ins_pad"], True)
+            num_data = []  # data, but represented as nums rather than b strings
+            for d in data:
+                num_data.append(d)
+            num_data[0x14E] = (kong["ins_tex"][0] >> 8) & 0xFF
+            num_data[0x14F] = (kong["ins_tex"][0] >> 0) & 0xFF
+            num_data[0x0DE] = (kong["ins_tex"][1] >> 8) & 0xFF
+            num_data[0x0DF] = (kong["ins_tex"][1] >> 0) & 0xFF
+            data = bytearray(num_data)  # convert num_data back to binary string
+            writeRawFile(TableNames.ModelTwoGeometry, kong["ins_pad"], True, data, ROM_COPY)
     if HOLIDAY == Holidays.no_holiday:
         barrel_color = None
         change_barrel_color = IsColorOptionSelected(settings, ColorOptions.barrels_and_boulders)
@@ -160,7 +207,7 @@ def applyHolidayMode(settings, ROM_COPY: ROM):
             for _ in range(3):
                 col_array.append(settings.random.randint(0, 0xFF))
             barrel_color = tuple(col_array)
-        changeBarrelColor(settings, ROM_COPY, barrel_color, None, change_barrel_color)  # Fixes some Krusha stuff
+        changeBarrelColor(settings, ROM_COPY, [barrel_color] * 6, None, change_barrel_color)  # Fixes some Krusha stuff
         return
     if HOLIDAY == Holidays.Christmas:
         # Set season to Christmas
@@ -258,14 +305,14 @@ def applyHolidayMode(settings, ROM_COPY: ROM):
             ROM_COPY.seek(getPointerLocation(TableNames.TexturesGeometry, 0xE68))
             ROM_COPY.writeBytes(tiny_hair_data)
         # Tag Barrel, Bonus Barrel & Transform Barrels
-        changeBarrelColor(settings, ROM_COPY, None, (0x00, 0xC0, 0x00))
+        changeBarrelColor(settings, ROM_COPY, [None] * 6, (0x00, 0xC0, 0x00))
     elif HOLIDAY == Holidays.Halloween:
         ROM_COPY.seek(settings.rom_data + 0xDB)
         ROM_COPY.writeMultipleBytes(1, 1)
         # Pad Rim
         applyCelebrationRims(ROM_COPY, -12)
         # Tag Barrel, Bonus Barrel & Transform Barrels
-        changeBarrelColor(settings, ROM_COPY, (0x8D, 0xB3, 0x93))
+        changeBarrelColor(settings, ROM_COPY, [(0x8D, 0xB3, 0x93)] * 6)
         # Turn Ice Tomato Orange
         sizes = {
             0x1237: 700,
@@ -283,7 +330,7 @@ def applyHolidayMode(settings, ROM_COPY: ROM):
         for img in range(0x1237, 0x1241 + 1):
             hueShiftImageContainer(25, img, 1, sizes[img], TextureFormat.RGBA5551, 171, ROM_COPY)
     elif HOLIDAY == Holidays.Anniv25:
-        changeBarrelColor(settings, ROM_COPY, (0xFF, 0xFF, 0x00), None, True)
+        changeBarrelColor(settings, ROM_COPY, [(0xFF, 0xFF, 0x00)] * 6, None, True)
         sticker_im = getImageFile(ROM_COPY, 25, getBonusSkinOffset(ExtraTextures.Anniv25Sticker), True, 1, 1372, TextureFormat.RGBA5551)
         vanilla_sticker_im = getImageFile(ROM_COPY, 25, 0xB7D, True, 1, 1372, TextureFormat.RGBA5551)
         sticker_im_snipped = sticker_im.crop((0, 0, 1, 1360))
